summaryrefslogtreecommitdiffstats
path: root/tderadio3/src/stationlist.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tderadio3/src/stationlist.cpp')
-rw-r--r--tderadio3/src/stationlist.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/tderadio3/src/stationlist.cpp b/tderadio3/src/stationlist.cpp
index 45ed4ca..2478e4e 100644
--- a/tderadio3/src/stationlist.cpp
+++ b/tderadio3/src/stationlist.cpp
@@ -20,7 +20,7 @@
#include "include/utils.h"
#include "include/stationlist.h"
#include "include/stationlistxmlhandler.h"
-#include "include/kradioversion.h"
+#include "include/tderadioversion.h"
#include <tqstring.h>
#include <tqfile.h>
@@ -378,14 +378,14 @@ bool StationList::readXML (const KURL &url, const IErrorLogClient &logger, bool
presetFile.reset();
// preset file written with kradio <= 0.2.x
if (tmp.find("<format>") < 0) {
logger.logInfo(i18n("Old Preset File Format detected"));
TQTextStream ins(&presetFile);
ins.setEncoding(TQTextStream::Locale);
xmlData = ins.read();
}
// preset file written with kradio >= 0.3.0
else {
TQXmlInputSource tmp(TQT_TQIODEVICE(&presetFile));
xmlData = tmp.data();
@@ -413,7 +413,7 @@ TQString StationList::writeXML (const IErrorLogClient &/*logger*/) const
t + xmlOpenTag(StationListElement) +
tt + xmlTag(StationListFormat, STATION_LIST_FORMAT) +
tt + xmlOpenTag(StationListInfo) +
- ttt + xmlTag(StationListInfoCreator, "kradio-" KRADIO_VERSION) +
+ ttt + xmlTag(StationListInfoCreator, "tderadio-" KRADIO_VERSION) +
ttt + xmlTag(StationListInfoMaintainer, m_metaData.maintainer) +
ttt + xmlTag(StationListInfoChanged, m_metaData.lastChange.toString(Qt::ISODate)) +
ttt + xmlTag(StationListInfoCountry, m_metaData.country) +
@@ -378,14 +378,14 @@ bool StationList::readXML (const KURL &url, const IErrorLogClient &logger, bool
presetFile.reset();
- // preset file written with kradio <= 0.2.x
+ // preset file written with tderadio <= 0.2.x
if (tmp.find("<format>") < 0) {
logger.logInfo(i18n("Old Preset File Format detected"));
@@ -378,14 +378,14 @@ bool StationList::readXML (const KURL &url, const IErrorLogClient &logger, bool
xmlData = ins.read();
}
- // preset file written with kradio >= 0.3.0
+ // preset file written with tderadio >= 0.3.0
else {
TQXmlInputSource tmp(TQT_TQIODEVICE(&presetFile));